<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" >
  <xsl:template match="root">
    <!--ツリー描画の始め-->
    <xsl:variable name="divIndexBase">0</xsl:variable>
    <div class="sm_frame" style="margin-left:10px">
      <xsl:attribute name="id">
        <xsl:text>div</xsl:text>
        <xsl:value-of select="$divIndexBase"/>
      </xsl:attribute>
      <xsl:for-each select="PrinterConfig/DeviceExplorer/Tree/Content/Item">
        <xsl:call-template name="createNode">
          <xsl:with-param name="divIndexBase" select="$divIndexBase"></xsl:with-param>
        </xsl:call-template>
      </xsl:for-each>
    </div>
  </xsl:template>
  
  
  <!--ノードのアイコンと文字列を描く。-->
  <xsl:template name="createNode">
    <!--引数-->
    <xsl:param name="divIndexBase"></xsl:param>
    <!--変数-->
    <xsl:variable name="Printerkey" select="/root/PrinterConfig/ActivePrinter/Item/@PrinterKey"></xsl:variable>
    <xsl:variable name="Shimuke" select="/root/PrinterConfig/Destination/Item/@Region"></xsl:variable>
    <xsl:variable name="newDivIndex">
        <xsl:value-of select="$divIndexBase"/>
        <xsl:text>-</xsl:text>
        <xsl:value-of select="position()"/>
    </xsl:variable>
	<xsl:variable name="activeIndex">
        <xsl:value-of select="substring($newDivIndex,3)"/>
    </xsl:variable>
    <!--ファイルはツリーに表示しない。-->
    <xsl:if test="@Type!='file'">
        <div>
            <!--三角アイコン。-->
            <img class="sm_enabled_icon">
              <xsl:attribute name="id">
                <xsl:text>img</xsl:text>
                <xsl:value-of select="$newDivIndex"/>
              </xsl:attribute>
              <!--右三角か、下三角を判断。-->
              <xsl:attribute name="src">
                <xsl:if test="@Status= 'opened'">
                  <xsl:text>../StorageManager/images/device_tree_minus.gif</xsl:text>
                </xsl:if>
                <xsl:if test="@Status= 'closed'">
                  <xsl:text>../StorageManager/images/device_tree_plus.gif</xsl:text>
                </xsl:if>
              </xsl:attribute>
              <xsl:attribute name="name">
                <xsl:if test="@Status= 'opened'">
                  <xsl:text>openedNode</xsl:text>
                </xsl:if>
                <xsl:if test="@Status= 'closed'">
                  <xsl:text>closedNode</xsl:text>
                </xsl:if>
              </xsl:attribute>
              <!--アイコンクリック動作定義-->
              <xsl:attribute name="onclick">
                <xsl:text>OnCallModule2("m_updateActivePrinter","</xsl:text>
                <xsl:value-of select="$Printerkey"></xsl:value-of>
                <xsl:text>");</xsl:text>
                <xsl:text>device_showHide("div","</xsl:text>
                <xsl:value-of select="$newDivIndex"/>
                <xsl:text>",this,"</xsl:text>
                <xsl:value-of select="@EverOpened"/>
                <xsl:text>","</xsl:text>
                <xsl:value-of select="$Shimuke"/>
                <xsl:text>")</xsl:text>
              </xsl:attribute>
    		  <!--マウス近づく動作定義-->
    		  <xsl:if test="$activeIndex != /root/PrinterConfig/DeviceExplorer/Tree/ChosenNode/Item/@nodeIndexPath">
    			<xsl:attribute  name="onmouseover">
    				<xsl:text>device_nodeOnMouseOver("</xsl:text>
    				<xsl:value-of select="$newDivIndex"/>
    				<xsl:text>")</xsl:text>
    			</xsl:attribute>
    		  </xsl:if>
    		  <!--マウスが外れる動作定義-->
    		  <xsl:if test="$activeIndex != /root/PrinterConfig/DeviceExplorer/Tree/ChosenNode/Item/@nodeIndexPath">
    			<xsl:attribute  name="onmouseout">
    				<xsl:text>device_nodeOnMouseOut("</xsl:text>
    				<xsl:value-of select="$newDivIndex"/>
    				<xsl:text>")</xsl:text>
    			</xsl:attribute>
    		  </xsl:if>
            </img>
            <!--アイテムアイコン-->
            <img class="sm_disabled_icon">
                <xsl:attribute name="src">
                    <xsl:choose>
                      <xsl:when test="@Type= 'printer'">
                        <xsl:text>../StorageManager/images/device_tree_printer.gif</xsl:text>
                      </xsl:when>
                      <xsl:when test="@Type= 'hdd'">
                        <xsl:text>../StorageManager/images/device_tree_hdd.gif</xsl:text>
                      </xsl:when>
                      <xsl:when test="@Type= 'sd'">
                        <xsl:text>../StorageManager/images/device_tree_sd.gif</xsl:text>
                      </xsl:when>
                      <xsl:when test="@Type= 'flash'">
                        <xsl:text>../StorageManager/images/device_tree_flash.gif</xsl:text>
                      </xsl:when>
                      <xsl:when test="@Type= 'pjl'">
                        <xsl:text>../StorageManager/images/device_tree_pjl.gif</xsl:text>
                      </xsl:when>
                      <xsl:when test="@Type= 'com'">
                        <xsl:text>../StorageManager/images/device_tree_com.gif</xsl:text>
                      </xsl:when>
                      <xsl:when test="@Type= 'ps'">
                        <xsl:text>../StorageManager/images/device_tree_ps.gif</xsl:text>
                      </xsl:when>
                      <xsl:when test="@Type= 'folder'">
                        <xsl:text>../StorageManager/images/device_tree_folder.gif</xsl:text>
                      </xsl:when>
                    </xsl:choose>
                </xsl:attribute>
            </img>
            
            <!--文字列。-->
            <span class="sm_treetext">
              <xsl:attribute name="id" >
                <xsl:text>span</xsl:text>
                <xsl:value-of select="$newDivIndex"/>
              </xsl:attribute>
              <xsl:if test="$activeIndex = /root/PrinterConfig/DeviceExplorer/Tree/ChosenNode/Item/@nodeIndexPath">
                <xsl:attribute name="class">
                  <xsl:text>sm_treetext_active</xsl:text>
                </xsl:attribute>
              </xsl:if>
              <xsl:value-of select="@Name"/>
            </span>
            <!--子ノードを格納するDIVを描くテンプレットを呼び出す-->
            <!--このノードが閉じられたなら、作成するDIVを見えないようにする-->
            <xsl:choose>
              <xsl:when test="@Status= 'opened'">
                <xsl:call-template name="createFrame">
                  <xsl:with-param name="newDivIndex" select="$newDivIndex"></xsl:with-param>
                  <xsl:with-param name="visiable" select="1"></xsl:with-param>
                </xsl:call-template>
              </xsl:when>
              <xsl:when test="@Status= 'closed'">
                <xsl:call-template name="createFrame">
                  <xsl:with-param name="newDivIndex" select="$newDivIndex"></xsl:with-param>
                  <xsl:with-param name="visiable" select="0"></xsl:with-param>
                </xsl:call-template>
              </xsl:when>
            </xsl:choose>
        </div>
        </xsl:if>
    
  </xsl:template>

  <!--ノードの子ノードを格納するDIVを描く-->
  <xsl:template name="createFrame">
    <xsl:param name="newDivIndex"></xsl:param>
    <xsl:param name="visiable"></xsl:param>
    <div class="sm_tree_subcontainer_visible">
      <xsl:attribute name="id">
        <xsl:text>div</xsl:text>
        <xsl:value-of select="$newDivIndex"/>
      </xsl:attribute>
      <xsl:if test="$visiable= 0">
        <xsl:attribute name="class">
          <xsl:text>sm_tree_subcontainer_invisible</xsl:text>
        </xsl:attribute>
      </xsl:if>
      <xsl:for-each select="Item">
        <xsl:call-template name="createNode">
          <xsl:with-param name="divIndexBase" select="$newDivIndex"></xsl:with-param>
        </xsl:call-template>
      </xsl:for-each>
    </div>
  </xsl:template>
</xsl:stylesheet>